@@ -6,5 +6,5 @@ from django.urls import re_path
 from core_module_raw_xml_app.views.views import RawXmlModule
 
 urlpatterns = [
-    re_path(r'module-raw-xml', RawXmlModule.as_view(), name='core_module_raw_xml_view'),
+    re_path(r"module-raw-xml", RawXmlModule.as_view(), name="core_module_raw_xml_view"),
 ]
